# BlackFoxPython

Python package for communication with BlackFoxWebAPI

- API version: v1
- Package version: 1.0.0

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

Download [blackfox-0.0.1.tar.gz](https://github.com/tmrdja/BlackFoxPython/raw/master/dist/blackfox-0.0.1.tar.gz)

```sh
pip install blackfox-0.0.1.tar.gz
```

You can install directly from Github

```sh
pip install git+https://github.com/tmrdja/BlackFoxPython.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/tmrdja/BlackFoxPython.git`)

Then import the package:
```python
import blackfox 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import blackfox
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run examples

## Documentation For Models

 - [KerasHiddenLayerConfig](docs/KerasHiddenLayerConfig.md)
 - [KerasLayerConfig](docs/KerasLayerConfig.md)
 - [KerasOptimizationConfig](docs/KerasOptimizationConfig.md)
 - [KerasOptimizationStatus](docs/KerasOptimizationStatus.md)
 - [KerasOptimizedNetwork](docs/KerasOptimizedNetwork.md)
 - [KerasTrainingConfig](docs/KerasTrainingConfig.md)
 - [OptimizationEngineConfig](docs/OptimizationEngineConfig.md)
 - [PredictionArrayConfig](docs/PredictionArrayConfig.md)
 - [PredictionFileConfig](docs/PredictionFileConfig.md)
 - [Range](docs/Range.md)
 - [TrainedNetwork](docs/TrainedNetwork.md)




